Crate git_sshripped_filter
git_
sshripped_
filter
0.9.0
All Items
Crate Items
Functions
Crate
git_
sshripped_
filter
Functions

clean
Encrypt content for staging via the Git clean filter.
diff
Decrypt content for textconv diff display.
smudge
Decrypt content for checkout via the Git smudge filter.