clean

Function clean 

pub fn clean(
    algorithm: EncryptionAlgorithm,
    repo_key: Option<&[u8]>,
    path: &str,
    content: &[u8],
) -> Result<Vec<u8>>
Encrypt content for staging via the Git clean filter.

Errors

Returns an error if the repository is locked (no key available) and the content is unencrypted, or if encryption itself fails.