smudge

Function smudge 

pub fn smudge(
    repo_key: Option<&[u8]>,
    path: &str,
    content: &[u8],
) -> Result<Vec<u8>>
Decrypt content for checkout via the Git smudge filter.

Errors

Returns an error if decryption fails. When the repository is locked, ciphertext is passed through unchanged.